@@ -22,6 +22,7 @@
     (riece-keyword . "Detect keywords in IRC buffers.")
     (riece-log . "Save IRC logs.")
     (riece-lsdb . "Help register nicknames in LSDB rolodex program.")
+    (riece-mcat . "Translate messages.")
     (riece-menu . "Setup Riece's command menus.")
     (riece-mini . "Use Riece only on the minibuffer.")
     ;;(riece-ndcc . "DCC file sending protocol support (written in elisp.)")
@@ -29,6 +30,7 @@
     (riece-shrink-buffer . "Free old IRC messages to save memory usage.")
     (riece-skk-kakutei . "Remove SKK's preedit mark before sending messages.")
     (riece-toolbar . "Display toolbar icons.")
+    (riece-twitter . "Send your status to Twitter.")
     (riece-unread . "Mark channels where new messages arrived.")
     (riece-url . "Collect URL in IRC buffers.")
     (riece-xface . "Display X-Face in IRC buffers.")
